@@ -15,10 +15,12 @@
 
 NNS.distance <- function(rpm, rpm_class, dist.estimate, type, k, n){
   type <- toupper(type)
-  n <- length(dist.estimate)
   l <- nrow(rpm)
   y.hat <- rpm$y.hat
   raw.dist.estimate <- unlist(dist.estimate)
+  n <- length(raw.dist.estimate)
+
+
 
   if(type!="FACTOR"){
     rpm <- rbind(as.list(t(dist.estimate)), rpm[, .SD, .SDcols = 1:n])
@@ -29,14 +31,12 @@ NNS.distance <- function(rpm, rpm_class, dist.estimate, type, k, n){
 
   rpm$y.hat <- y.hat
 
-  rpm_mat <- t(rpm[, 1:n])
-
   if(type=="L2"){
-    rpm$Sum <- Rfast::rowsums(t(rpm_mat - dist.estimate)^2 + (1/l + (rpm_class == raw.dist.estimate))^-1, parallel = TRUE)
+    rpm$Sum <- Rfast::rowsums( t((t(rpm[, 1:n]) - dist.estimate)^2) * ((l - (rpm_class == raw.dist.estimate))/l), parallel = TRUE)
   }
 
   if(type=="L1"){
-    rpm$Sum <- Rfast::rowsums(abs(t(rpm_mat - dist.estimate)) + (1/l + (rpm_class == raw.dist.estimate))^-1, parallel = TRUE)
+    rpm$Sum <- Rfast::rowsums(abs(t(t(rpm[, 1:n]) - dist.estimate)) * ((l - (rpm_class == raw.dist.estimate))/l), parallel = TRUE)
   }
 
   if(type=="DTW"){
@@ -49,8 +49,10 @@ NNS.distance <- function(rpm, rpm_class, dist.estimate, type, k, n){
 
   rpm$Sum[rpm$Sum == 0] <- 1e-10
 
+
   data.table::setkey(rpm, Sum)
 
+
   if(k==1){
     index <- which(rpm$Sum==min(rpm$Sum))
     if(length(index)>1){
@@ -62,18 +64,20 @@ NNS.distance <- function(rpm, rpm_class, dist.estimate, type, k, n){
 
   rpm <- rpm[1:min(k,l),]
 
-  inv <- 1 / rpm$Sum
-  emp_weights <- inv / sum(inv)
+  uni_weights <- rep(1/min(k,l), min(k,l))
 
-  norm_weights <- pmin(max(rpm$Sum), dnorm(rpm$Sum, mean(rpm$Sum), sd(rpm$Sum)))
-  norm_weights <- norm_weights / sum(norm_weights)
+  emp <- rpm$Sum^(-1/min(k,l))
+  emp_weights <- emp / sum(emp)
 
-  t_weights <- pmin(max(rpm$Sum), dt(x = rpm$y.hat, df = min(k,l)))
-  t_weights <- t_weights/sum(t_weights)
+  exp <- dexp(1:min(k,l), rate = 1/min(k,l))
+  exp_weights <- exp / sum(exp)
 
-  weights <- (emp_weights + norm_weights + t_weights)/sum(emp_weights + norm_weights + t_weights)
+  lnorm <- abs(rev(dlnorm(1:min(k, l), meanlog = min(k, l), sdlog = min(k, l), log = TRUE)))
+  lnorm_weights <- lnorm / sum(lnorm)
 
-  single.estimate <- weights%*%rpm$y.hat
+  weights <- (emp_weights + exp_weights + lnorm_weights + uni_weights)/sum(emp_weights + exp_weights + lnorm_weights + uni_weights)
+
+  single.estimate <- rpm$y.hat%*%weights
 
   return(single.estimate)
 }
