@@ -2,7 +2,7 @@
 
 #' @importFrom grDevices adjustcolor rainbow rgb
 #' @importFrom graphics abline boxplot legend lines par plot points segments text matplot title axis mtext barplot hist strwidth
-#' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat qnorm model.matrix fivenum acf qt ecdf time approx embed frequency is.ts runif start ts optim quantile optimize dnorm dt
+#' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat qnorm model.matrix fivenum acf qt ecdf time approx embed frequency is.ts runif start ts optim quantile optimize dnorm dlnorm dexp dt .preformat.ts
 #' @importFrom utils globalVariables head tail combn flush.console
 #' @importFrom data.table data.table %chin% .I .N .SD := as.data.table fwrite is.data.table rbindlist set setcolorder setnames setorder as.IDate as.ITime setkey frollmean shift transpose
 #' @importFrom dtw dtw
@@ -11,6 +11,7 @@
 #' @importFrom Rfast colsums colmeans rowsums rowmeans
 #' @importFrom caret upSample downSample
 #' @importFrom plyr is.discrete
+#' @importFrom zoo as.yearmon
 #' @import doParallel
 #' @import rgl
 #' @import stringr
@@ -18,6 +19,7 @@
 #' @import tdigest
 #' @import data.table
 #' @import dynlm
+#' @import Quandl
 
 
 
@@ -48,7 +50,7 @@
   requireNamespace("tdigest")
   requireNamespace("Rfast")
   requireNamespace("dynlm")
-
+  requireNamespace("Quandl")
 
   .datatable.aware = TRUE
 
