@@ -1,8 +1,8 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE)
-require(NNS)
 
-## ----mean---------------------------------------------------------------------
+## ----mean, message=FALSE------------------------------------------------------
+library(NNS)
 set.seed(123) ; x = rnorm(100) ; y = rnorm(100)
 
 mean(x)
